.. _nki_dataset:

NKI enhanced surface dataset
============================

Access
------
See :func:`nilearn.datasets.fetch_surf_nki_enhanced`
and :func:`nilearn.datasets.load_nki`.

Notes
-----
Enhanced Nathan Kline Institute-Rockland Sample resting state fMRI data
(TR=645ms) of 102 subjects, preprocessed and projected to the fsaverage5 surface
according to https://github.com/fliem/nki_nilearn.
Contains phenotypical metadata.

Direct download link: http://fcon_1000.projects.nitrc.org/indi/enhanced/.

See :footcite:t:`Nooner2012`.

Content
-------

This refers to the content returned by
:func:`nilearn.datasets.fetch_surf_nki_enhanced`.

:'func_left': :term:`resting-state` data for the left hemisphere
:'func_right': :term:`resting-state` data for the right hemisphere
:'phenotypic': phenotypical metadata

References
----------
.. footbibliography::

License
-------
unknown
